diff lwasm/lwasm.h @ 206:080bb67d84f2

Add export pragma Added a pragma "export" which causes all exportable symbols to be exported automatically.
author William Astle <lost@l-w.ca>
date Thu, 24 May 2012 17:28:15 -0600
parents 17bd59f045af
children 07e1fac76321
line wrap: on
line diff
--- a/lwasm/lwasm.h	Wed May 23 19:37:30 2012 -0600
+++ b/lwasm/lwasm.h	Thu May 24 17:28:15 2012 -0600
@@ -82,7 +82,8 @@
 	PRAGMA_PCASPCR = 0x0020,			// treats ,PC as ,PCR instead of constant offset
 	PRAGMA_SHADOW = 0x0040,				// allow macros to shadow builtin operations
 	PRAGMA_NOLIST = 0x0080,				// don't show line in listing
-	PRAGMA_AUTOBRANCHLENGTH = 0x0100	// automatically select proper length for relative branches
+	PRAGMA_AUTOBRANCHLENGTH = 0x0100,	// automatically select proper length for relative branches
+	PRAGMA_EXPORT = 0x0200				// export symbols by default, unless local
 };